# Installation

Installation is standard. If you are using
[pipx](https://pipx.pypa.io/){:target="_blank"} (recommended) install it as:

```console
pipx install lice2
```

Otherwise use `pip` as standard:

```console
pip install lice2
```

## Development Version

If you want to install the development version to try out new features before
they are release, you can do so with the following command:

```console
pipx install git+https://github.com/seapagan/lice2.git
```

or

```console
pip install git+https://github.com/seapagan/lice2.git
```

## Autocompletion

To enable autocompletion for lice options, run the following command after
installation:

```console
lice --install-completion
```
